'use strict';
const through2 = require('through2');
const scanner_1 = require('../services/scanner');
const resolver_1 = require('../providers/resolver');
const paths_1 = require('../utils/paths');
class Stream {
    constructor(root, storage, language, options) {
        this.root = root;
        this.storage = storage;
        this.language = language;
        this.options = options;
        // :)
    }
    run(filepath, stats) {
        const scanner = new scanner_1.Scanner(this.root, this.storage, this.language, this.options);
        const resolver = new resolver_1.Resolver(this.storage);
        const root = this.root;
        const log = this.options.log;
        return through2.obj(function (file, enc, cb) {
            // Protection for bad filepath
            if (!filepath) {
                this.push(file);
                return cb();
            }
            const mainFile = paths_1.join(root, file.relative);
            const changedFile = paths_1.normalize(filepath);
            // Update Storage
            scanner.scan(filepath, stats).then(() => {
                if (resolver.checkDependency(mainFile, changedFile)) {
                    this.push(file);
                    log(mainFile);
                    return cb();
                }
                cb();
            }).catch(cb);
        });
    }
}
exports.Stream = Stream;
